#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class InstallationVersion:
    def __init__(self):
        self.databaseVersion = None
        self.softwareVersion = None
        self.versionName = None
        self.needsUpgrade = None
        pass


class __InstallationVersionSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = InstallationVersion()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        databaseVersionValue = value['databaseVersion']
        instance.databaseVersion = serder.STRING.parse(databaseVersionValue)
        softwareVersionValue = value['softwareVersion']
        instance.softwareVersion = serder.STRING.parse(softwareVersionValue)
        versionNameValue = value['versionName']
        instance.versionName = serder.STRING.parse(versionNameValue)
        needsUpgradeValue = value['needsUpgrade']
        instance.needsUpgrade = serder.BOOLEAN.parse(needsUpgradeValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        databaseVersionValue = value.databaseVersion
        instance["databaseVersion"] = serder.STRING.encode(
            databaseVersionValue)
        softwareVersionValue = value.softwareVersion
        instance["softwareVersion"] = serder.STRING.encode(
            softwareVersionValue)
        versionNameValue = value.versionName
        instance["versionName"] = serder.STRING.encode(versionNameValue)
        needsUpgradeValue = value.needsUpgrade
        instance["needsUpgrade"] = serder.BOOLEAN.encode(needsUpgradeValue)
        return instance
